function f = IHccXYBICPerteHubercc(Xtr,Ytr,G)
%%%Inputs:
%Xtr design matrix of the training sample
%Ytr labels vector of the training sample
%G  grid for the BIC Criterion

%%%Outputs: 
%f.stalphabeta estimations of s, tau, alpha and beta.
%f.lambdaopt regularization parameter.

q=length(G);
[n,p]=size(Xtr);
M=1.345;
%%%Calculating the unpenalized estimator on the whole training sample.

cvx_begin
variables alphaaOLS betaUNP(p) s v(n);
minimize (n*s+quad_over_lin(Ytr-alphaaOLS-Xtr*betaUNP-v,s)+2*M*norm(v,1))
subject to
s > 0;
cvx_end


%%% Calculating the estimators for each parameter of the grid and store all the corresponding estimations

%stalbet starts at 0
stalbet=zeros(p+3,q);

for j=1:q,
lambda=G(j);
H=IHccadapXYlambdaforBICPerteHubercc(Xtr,Ytr,lambda,betaUNP);
stalbet(:,j)=H.stalphabeta;
end

%%% Choice of the regularization parameter by BIC Criterion. 
%loss and pen start at 0
loss=zeros(1,q);
pen=zeros(1,q);

for j=1:q,
loss(:,j)=log(n*stalbet(1,j)+sum(huber((Ytr-stalbet(3,j)-Xtr*stalbet(4:p+3,j))./stalbet(1,j),M))*stalbet(1,j));
bool=abs(stalbet(4:p+3,j)) > 10^(-5);
pen(:,j)=(log(n)/(2*n))*sum(bool);
BIC=loss+pen;
end

[a,b]=min(BIC);
lambdaBIC=G(b);

f.stalphabeta=stalbet(:,b);
f.lambdaopt=lambdaBIC;
