function f = PerteHuberccPenL1Adap(n,m,u,sig,G,M)
%%%Inputs:
%n size of each training sample.
%m size of the test sample.
%u proportion of outliers.
%sig a parameter of the model (not necessarily the variance of the noise).
%G grid for the BIC choice of lambda
%M number of training samples.

%%%Outputs:
%f.salphabeta estimations of s, alpha and beta.
%f.RPE Relative Prediction Error.
%f.lambdaopt regularization parameters.

%intercept of the model
alpha0=1;

%coefficient of each covariable
beta0=[3*ones(15,1);zeros(25,1)];
p=length(beta0);

%alphabeta starts at 0
salphabeta=zeros(p+2,M);

%lambdaopt starts at 0
lambdaopt=zeros(1,M); 

% Reseting the generator of random numbers to its initial state 

rand('state',0); 

randn('state',0);

%generating the design matrix of each training sample

Xtr=XgenerationVeryStrongCorrGroupEffect(n);

%generating the test sample

Xte=XgenerationVeryStrongCorrGroupEffect(m);

for j=1:M,

%generating the labels of the training sample according to the model
Ytr=alpha0+Xtr*beta0+sig*mixtgaussrnd(u,n)';

%Calculation of the estimator on the training sample
H=penL1XYBICPerteHcc(Xtr,Ytr,G);
salphabeta(:,j)=H.salphabeta;
lambdaopt(j)=H.lambdaopt;

end
%Calculation of the RPE on the test set
beta=salphabeta(3:end,:);
alpha=salphabeta(2,:);
betaerr=beta-repmat(beta0,1,M);
alphaerr=alpha-repmat(alpha0,1,M);
alphaerr1=repmat(alphaerr,m,1);
alphabetaerr=alphaerr1+Xte*betaerr;
RPE=mean(alphabetaerr.^2,1)/(sig^2*(1+(225-1)*u));

f.salphabeta=salphabeta;
f.RPE=RPE;
f.lambdaopt=lambdaopt;


save salphabeta2400LassoBICHubercc.dat -ASCII salphabeta
save RPE2400LassoBICHubercc.dat -ASCII RPE
save lambdaopt2400LassoBICHubercc.dat -ASCII lambdaopt


