function f = IHccXYBIC(Xtr,Ytr,G1,G2)
%%%Inputs:
%Xtr design matrix of the training sample
%Ytr labels vector of the training sample
%G1  grid for the BIC choice of lambda1
%G2 grid for the BIC choice of L

%%%Outputs: 
%f.talphabeta estimations of tau, alpha and beta.
%f.lambdaopt regularization parameter.

q1=length(G1);
q2=length(G2);
[n,p]=size(Xtr);

%%%Calculating the unpenalized estimator on the whole training sample.

cvx_begin
variables alphaaOLS betaUNP(p);
minimize (quad_over_lin(Ytr-alphaaOLS-Xtr*betaUNP,1))
cvx_end


%%% Calculating the estimators for each parameter of the grid and store all the corresponding estimations
%loss and pen start at 0
loss=zeros(q1,q2);
pen=zeros(q1,q2);

for i=1:q1,
for j=1:q2
lambda=G1(i);
L=G2(j);
H=IHccadapXYlambdaforBIC(Xtr,Ytr,lambda,L,betaUNP);
loss(i,j)=log(quad_over_lin(Ytr-H.talphabeta(2)-Xtr*H.talphabeta(3:p+2),1));
bool=abs(H.talphabeta(3:p+2)) > 10^(-5);
pen(i,j)=(log(n)/n)*sum(bool);
end
end

BIC=loss+pen;
[a,b]=min(BIC);
[c,d]=min(a);
Lopt=G2(d);
lambdaopt=G1(b(d));


H=IHccadapXYlambdaforBIC(Xtr,Ytr,lambdaopt,Lopt,betaUNP);


f.talphabeta=H.talphabeta;
f.lambdaopt=lambdaopt;
f.Lopt=Lopt;

f.betaUNP=betaUNP;
f.loss=loss;
f.pen=pen;
