function f = PerteQuadratiquePenIHccAdap(n,m,u,sig,G1,G2,M)
%%%Inputs:
%n size of each training sample.
%m size of the test sample.
%u proportion of outliers
%G1 grid for the BIC choice of lambda
%G2 grid for the BIC choise of L
%sig a parameter of the model (not necessarily the variance of the noise).
%M number of training samples.

%%%Outputs:
%f.talphabeta estimations of tau, alpha and beta.
%f.RPE Relative Prediction Error.
%f.lambdaopt regularization parameter.

%intercept of the model
alpha0=1;

%coefficient of each covariable
beta0=[3*ones(15,1);zeros(25,1)];
p=length(beta0);

%talphabeta starts at 0
talphabeta=zeros(p+2,M);

%lambdaopt starts at 0
lambdaopt=zeros(1,M); 

%Lopt starts at 0
Lopt=zeros(1,M);

% Reseting the generator of random numbers to its initial state 

rand('state',0); 

randn('state',0);

%generating the design matrix of each training sample

Xtr=XgenerationVeryStrongCorrGroupEffect(n);

%generating the test sample

Xte=XgenerationVeryStrongCorrGroupEffect(m);

%la division par sqrt{1+(15^2-1)*u} assurerait que le bruit que l'on ajoute est de la forme sig*eps avec var(eps)=1. Cependant, augmenter la proportion u d'oulier diminue la variance du bruit : compense le fait que le probleme est plus dur.

for j=1:M,

%generating the labels of the training sample according to the model
Ytr=alpha0+Xtr*beta0+sig*mixtgaussrnd(u,n)';

%Calculation of the estimator on the training sample
G=IHccXYBIC(Xtr,Ytr,G1,G2);
talphabeta(:,j)=G.talphabeta;
lambdaopt(:,j)=G.lambdaopt;
Lopt(:,j)=G.Lopt;
loss=G.loss;
pen=G.pen;
end
%Calculation of the RPE on the test set
beta=talphabeta(3:end,:);
alpha=talphabeta(2,:);
betaerr=beta-repmat(beta0,1,M);
alphaerr=alpha-repmat(alpha0,1,M);
alphaerr1=repmat(alphaerr,m,1);
%sqte=sqrt(sum(Xte.^2));
%alphabetaerr=alphaerr1+(Xte*diag(1./sqte))*betaerr;
alphabetaerr=alphaerr1+Xte*betaerr;
RPE=mean(alphabetaerr.^2,1)/(sig^2*(1+(225-1)*u));


f.talphabeta=talphabeta;
f.RPE=RPE;
f.lambdaopt=lambdaopt;
f.Lopt=Lopt;

f.loss=loss;
f.pen=pen;
%save alphabeta350LassoBIC.dat -ASCII alphabeta
%save RPE350LassoBIC.dat -ASCII RPE
%save lambdaopt350LassoBIC.dat -ASCII lambdaopt


