function f = IHccXYBIC(Xtr,Ytr,G)
%%%Inputs:
%Xtr design matrix of the training sample
%Ytr labels vector of the training sample
%G  grid for the BIC Criterion

%%%Outputs: 
%f.talphabeta estimations of tau, alpha and beta.
%f.lambdaopt regularization parameter.

q=length(G);
[n,p]=size(Xtr);

%%%Calculating the unpenalized estimator on the whole training sample.

cvx_begin
variables alphaaOLS betaUNP(p);
minimize (quad_over_lin(Ytr-alphaaOLS-Xtr*betaUNP,1))
cvx_end


%%% Calculating the estimators for each parameter of the grid and store all the corresponding estimations

%talbet starts at 0
talbet=zeros(p+2,q);

for j=1:q,
lambda=G(j);
H=IHccadapXYlambdaforBIC(Xtr,Ytr,lambda,betaUNP);
talbet(:,j)=H.talphabeta;
end

%%% Choice of the regularization parameter by BIC Criterion. 
%loss and pen start at 0
loss=zeros(1,q);
pen=zeros(1,q);

for j=1:q,
loss(:,j)=log(quad_over_lin(Ytr-talbet(2,j)-Xtr*talbet(3:p+2,j),1));
bool=abs(talbet(3:p+2,j)) > 10^(-5);
pen(:,j)=(log(n)/n)*sum(bool);
BIC=loss+pen;
end

[a,b]=min(BIC);
lambdaBIC=G(b);

f.talphabeta=talbet(:,b);
f.lambdaopt=lambdaBIC;
%f.betaUNP=betaUNP;
