function f = PerteQuadratiquePenRidge(n,m,u,sig,G,M)
%%%Inputs:
%n size of each training sample.
%m size of the test sample.
%u proportion of outliers
%sig a parameter of the model (not necessarily the variance of the noise).
%G cross-validation grid for lambda.
%M number of training samples.

%%%Outputs:
%f.alphabeta estimations of alpha and beta.
%f.RPE Relative Prediction Error.
%f.lambdaopt regularization parameters.

%intercept of the model
alpha0=1;

%coefficient of each covariable
beta0=[3*ones(15,1);zeros(25,1)];
p=length(beta0);

%alphabeta starts at 0
alphabeta=zeros(p+1,M);

%lambdaopt starts at 0
lambdaopt=zeros(1,M); 

% Reseting the generator of random numbers to its initial state 

rand('state',0); 

randn('state',0);

%generating the design matrix of each training sample

Xtr=XgenerationVeryStrongCorrGroupEffect(n);

%generating the test sample

Xte=XgenerationVeryStrongCorrGroupEffect(m);

%la division par sqrt{1+(15^2-1)*u} assurerait que le bruit que l'on ajoute est de la forme sig*eps avec var(eps)=1. Cependant, augmenter la proportion u d'oulier diminue la variance du bruit : compense le fait que le probleme est plus dur.

for j=1:M,

%generating the labels of the training sample according to the model
Ytr=alpha0+Xtr*beta0+sig*mixtgaussrnd(u,n)';

%Calculation of the estimator on the training sample
H=RidgeXYcv(Xtr,Ytr,G);
alphabeta(:,j)=H.alphabeta;
lambdaopt(:,j)=H.lambdaopt;

end
%Calculation of the RPE on the test set
beta=alphabeta(2:end,:);
alpha=alphabeta(1,:);
betaerr=beta-repmat(beta0,1,M);
alphaerr=alpha-repmat(alpha0,1,M);
alphaerr1=repmat(alphaerr,m,1);
%sqte=sqrt(sum(Xte.^2));
%alphabetaerr=alphaerr1+(Xte*diag(1./sqte))*betaerr;
alphabetaerr=alphaerr1+Xte*betaerr;
RPE=mean(alphabetaerr.^2,1)/(sig^2*(1+(225-1)*u));


f.alphabeta=alphabeta;
f.RPE=RPE;
f.lambdaopt=lambdaopt;

save alphabeta2400RidgeCv.dat -ASCII alphabeta
save RPE2400RidgeCv.dat -ASCII RPE
save lambdaopt2400RidgeCv.dat -ASCII lambdaopt


